#!/bin/bash

#' ---
#' title: "Generate mRNA isoform pair features"
#' authors: "Gaurav Kandoi, Julie A. Dickerson"
#' date: "November 13, 2018"
#' affiliation: "Iowa State University of Science and Technology"
#' license: "CC BY 4.0"
#' ---


##xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx##
# This section generates the mRNA Isoform pair features using all the RNA-Seq samples.
Rscript fpkmPairs.R

for f in GRCm38.p4_K8mer_pairs*.csv
do
cat $f >> GRCm38.p4_FPKM_pairs.csv
done
##xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx##


##---------------------------------------##
# This section generates the mRNA Isoform pair features for individual tissues.
# tissueName = ["adrenal gland", "hindbrain", "large intestine", "forebrain", "embryonic facial prominence", "heart", "kidney", "limb", "liver", "lung", "midbrain", "neural tube", "ovary", "small intestine", "spleen", "stomach", "thymus"]
Rscript fpkmTissuePairs.R "tissueName"

for f in GRCm38.p4_K7mer_pairs*.csv
do
cat $f >> GRCm38.p4_tissueName_pairs.csv # Change file name accordingly.
done
##---------------------------------------##


##---------------------------------------##
# This section generates the mRNA Isoform pair features using mRNA sequence features.
# value_of_kmer:	int
# number_of_cores:	int
Rscript mrnaSeqPairs.R value_of_kmer number_of_cores

for f in GRCm38.p4_K7mer_pairs*.csv
do
cat $f >> GRCm38.p4_K3mer_pairs.csv # Change file name accordingly.
done
##---------------------------------------##


##---------------------------------------##
# This section generates the mRNA Isoform pair features using protein sequence features.
# value_of_kmer:	int
# number_of_cores:	int
Rscript protSeqPairs.R value_of_kmer number_of_cores

for f in GRCm38.p4_K7mer_pairs*.csv
do
cat $f >> GRCm38.p4_AAC_pairs.csv # Change file name accordingly.
done
##---------------------------------------##
