#' ---
#' title: "Perform comparison with previous method"
#' authors: "Gaurav Kandoi, Julie A. Dickerson"
#' date: "November 13, 2018"
#' affiliation: "Iowa State University of Science and Technology"
#' license: "CC BY 4.0"
#' ---

import numpy as np
from scipy import interp
import sklearn.metrics
import pandas as pd
import matplotlib as mpl

mpl.use('agg')

import matplotlib.pyplot as plt
from pylab import *

import random
import string
import time
from dfply import *


# Read the prediction results from the Multiple Instance Learning (MIL) based Bayesian network method.
UMich_Pred = pd.read_csv("../Data/Predictions/prediction_cut1.01._fold1._5.rna.gz", sep = "\t", header = None)
UMich_Pred.columns = ['V1', 'Prob', 'TrueLabel'] # Define column names. The first column contains the mRNA isoform pair IDs.
UMich_Pred >>= separate(UMich_Pred.V1, into = ['Trans1', 'Trans2'], sep = ",", remove = False) # Split the mRNA isoform pair IDs in two seperate columns.

# Read prediction results from TENSION.
My_Pred = pd.read_csv("../Predictions/MMU_Predictions_13Nov18.csv.gz", sep = ",", header = 0, index_col = 0)

# Combine the results from both methods.
Combined = UMich_Pred >> left_join(My_Pred)

# Calculate and plot the precision and recall curves for MIL based Bayesian network method and TENSION.
fig = plt.figure(figsize=(10, 10), dpi = 80)
plt.subplot(2,1,1)
precision, recall, _ = sklearn.metrics.precision_recall_curve(Combined['TrueLabel'], Combined['Prob'])
plt.step(recall, precision, label='Previous Method (AUC=%.4f)' % sklearn.metrics.average_precision_score(Combined['TrueLabel'], Combined['Prob']))
precision, recall, _ = sklearn.metrics.precision_recall_curve(Combined['TrueLabel'], Combined['prob_All'])
plt.step(recall, precision, label='TENSION (AUC=%.4f)' % (sklearn.metrics.average_precision_score(Combined['TrueLabel'], Combined['prob_All'])), color='brown')
plt.xlim([0.0, 1.0])
plt.ylim([0.0, 1.0])
plt.xlabel('Recall', fontsize = 17)
plt.ylabel('Precision', fontsize = 17)
plt.title('Precision-Recall curve for comparison with previous method', fontsize = 17)
plt.legend(loc="lower right", fontsize = 12)

# Calculate and plot the Receiver Operating Characteristic curve for MIL based Bayesian network method and TENSION.
plt.subplot(2,1,2)
precision, recall, _ = roc_curve(Combined['TrueLabel'], Combined['Prob'])
plt.plot(precision, recall, label='Previous Method (AUC=%.4f)' %  sklearn.metrics.roc_auc_score(Combined['TrueLabel'], Combined['Prob']))
precision, recall, _ = roc_curve(Combined['TrueLabel'], Combined['prob_All'])
plt.plot(precision, recall, label='TENSION (AUC=%.4f)' % (sklearn.metrics.roc_auc_score(Combined['TrueLabel'], Combined['prob_All'])), color='brown')
plt.plot([0, 1], [0, 1], linestyle='--', color='black', label='Random')
plt.xlim([0.0, 1.0])
plt.ylim([0.0, 1.0])
plt.xlabel('False Positive Rate', fontsize = 17)
plt.ylabel('True Positive Rate', fontsize = 17)
plt.title('Receiver operating characteristic curve for comparison with previous method', fontsize = 17)
plt.legend(loc="lower right", fontsize = 12)

# Save the plot to a file.
fig.tight_layout()
fig.savefig('../Data/Fig8.tiff')

