#' ---
#' title: "Run STAR and StringTie for RNA-Seq processing"
#' authors: "Gaurav Kandoi, Julie A. Dickerson"
#' date: "November 13, 2018"
#' affiliation: "Iowa State University of Science and Technology"
#' license: "CC BY 4.0"
#' ---

## Command line arguments used for STAR and StringTie to process the RNA-Seq datasets.
## All paths are relative to the current folder (Scripts)

## Make directories to store the output from STAR and StringTie
mkdir -p ../Data/Star_Output/read/
mkdir -p ../Data/StringTie_Output/read/
mkdir ../Data/STAR_Index/

## Decompress GTF Files
gzip -d ../Data/ref_GRCm38.p4_top_level.gff3.gz

## STAR
## Create STAR index (Run only once)
STAR --runMode genomeGenerate --runThreadN 24  --genomeDir ../Data/STAR_Index/ --genomeFastaFiles ../Data/mm_ref_GRCm38.p4_chr*.fa.edit 

## Run STAR using 24 cores and ~31GB memory and redirect output to the directory created above. We want the output to be sorted and in BAM format.
## For reads smaller than 100nt, also use --sjdbOverhang option and use (read length - 1) as the argument.
STAR --genomeDir ../Data/STAR_Index --runThreadN 24 --outSAMtype BAM SortedByCoordinate --outSAMstrandField intronMotif --chimOutType WithinBAM --chimSegmentMin 20 --sjdbGTFfile ../Data/ref_GRCm38.p4_top_level.gff3 --limitBAMsortRAM 31000000000 --readFilesIn read1.fastq read2.fastq --outFileNamePrefix ../Data/Star_Output/read/


## StringTie
## Run StringTie using 24 cores and redirect output to the directory created above.
stringtie ../Data/Star_Output/read/Aligned.sortedByCoord.out.bam -o ../Data/StringTie_Output/read/expression.gtf -p 24 -G ../Data/ref_GRCm38.p4_top_level.gff3 -A ../Data/StringTie_Output/read/expression.tab -C ../Data/StringTie_Output/read/transcripts.gtf -B
